package com.ruoyi.web.projectInfo.service;

import com.ruoyi.common.core.domain.entity.SysDept;
import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.enums.SysRoleEnum;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.mapper.SysDeptMapper;
import com.ruoyi.system.mapper.SysRoleMapper;
import com.ruoyi.web.projectInfo.mapper.WxProjectInfoMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author wxw
 * @version : V1.0
 * @ClassName: ProjectInfoServiceImpl
 * @Description: TODO
 * @Auther: Makalu
 * @Date: 2020/7/7 16:45
 */
@Service
public class WxProjectInfoServiceImpl implements WxIProjectInfoService {

    @Autowired
    private WxProjectInfoMapper ProjectInfoMapper;

    @Autowired
    private SysDeptMapper sysDeptMapper;

    @Autowired
    private SysRoleMapper sysRoleMapper;

    @Override
    public Map<String, Object> getDeptAll(Map<String,Object> map) {
        //当前登录账号角色信息
        String nowRole = Convert.toStr(sysRoleMapper.getUserMinRoleId(Convert.toLong(map.get("userId"))));
        Map<String,Object> dataMap = new HashMap<>(16);
        //组装数据
        dataMap.put("shengName","西安市");
        dataMap.put("shiName","西咸新区");
        dataMap.put("quName","泾河新城");
        //公司信息
        List<Map<String,Object>> list = new ArrayList<>();
        Map<String,Object> totalMap = new HashMap<>(16);
        //查询出公司信息
        if(SysRoleEnum.ADMIN.getCode().equals(nowRole) || SysRoleEnum.SUPR.getCode().equals(nowRole) || SysRoleEnum.JTGS.getCode().equals(nowRole) ){
            List<Map<String,Object>> companyList = ProjectInfoMapper.getZGSDeptInfoByMap(map);
            totalMap.put("id","0");
            totalMap.put("text","泾河产业发展集团");
            list.add(totalMap);
            for(Map<String,Object> companyMap:companyList){
                totalMap = new HashMap<>(16);
                totalMap.put("id",companyMap.get("dept_id"));
                totalMap.put("text",companyMap.get("dept_name"));
                list.add(totalMap);
            }
        }else if(SysRoleEnum.ZGS.getCode().equals(nowRole)){
            SysDept sysDept = this.getZGSDept(Convert.toLong(map.get("deptId")));
            totalMap.put("id",sysDept.getDeptId());
            totalMap.put("text",sysDept.getDeptName());
            list.add(totalMap);
        }else if(SysRoleEnum.COMMON.getCode().equals(nowRole)){
            //普通角色，获取真实部门
            SysDept sysDept = this.getZGSDept(Convert.toLong(map.get("deptId")));
            //判断当前部门是否是产业发展集团
            if("1".equals(sysDept.getTypeFlag())){
                sysDept = this.getZGSDept(Convert.toLong(sysDept.getDeptId()));
                totalMap.put("id",sysDept.getDeptId());
                totalMap.put("text",sysDept.getDeptName());
                list.add(totalMap);
            }else{
                //普通角色
                totalMap.put("id",sysDept.getDeptId());
                totalMap.put("text",sysDept.getDeptName());
                list.add(totalMap);
            }
        }else{
            //监理单位/总包单位/分包单位
            SysDept sysDept = sysDeptMapper.selectDeptById(Convert.toLong(map.get("deptId")));
            totalMap.put("id",sysDept.getDeptId());
            totalMap.put("text",sysDept.getDeptName());
            list.add(totalMap);
        }
        dataMap.put("province_list",list);
        dataMap.put("deptId",map.get("deptId"));
        dataMap.put("logCompanyName",list.get(0).get("text"));
        dataMap.put("companyId",list.get(0).get("text"));
        return dataMap;
    }

    @Override
    public Map<String, Object> selectDeptSubordinate(Map<String,Object> param) {
        List<Map<String,Object>> deptList = ProjectInfoMapper.getDeptSubordinate(param);
        Map<String,Object> dataMap = new HashMap<>(16);
        for(Map<String,Object> map:deptList){
            map.put("userId",param.get("userId"));
            dataMap.put(map.get("text").toString(),ProjectInfoMapper.getQUDeptSubordinate(map));
        }
        return dataMap;
    }

    @Override
    public List<Map<String, Object>> getProjectByDeptIdAndCompanyId(Map<String, Object> map) {
        List<Map<String,Object>> list = new ArrayList<>();
        String nowRole = Convert.toStr(sysRoleMapper.getUserMinRoleId(Convert.toLong(map.get("userId"))));
        if(SysRoleEnum.ZGS.getCode().equals(nowRole)){
            Long deptId = this.getZGSDept(Convert.toLong(map.get("deptId"))).getDeptId();
            map.put("nowDeptId",Convert.toStr(deptId));
        }else{
            map.put("nowDeptId",Convert.toStr(map.get("deptId")));
        }
        //当前角色时管理员时，修改角色为集团公司
        if(Convert.toInt(SysRoleEnum.JTGS.getCode())>Convert.toInt(nowRole)){
            nowRole = SysRoleEnum.JTGS.getCode();
        }
        map.put("nowRole",nowRole);
        List<Map<String, Object>> getProjec  = ProjectInfoMapper.getProjectByDeptIdAndCompanyId(map);
        for(int i=0;i<getProjec.size();i++){
            //视频接入数
            String videoNum = "0";
            //结构体监测点位数
            Integer monitoringCount = 0;
            //结构体监测预警个数
            Integer monitoringErrorCount = 0;
            getProjec.get(i).put("id",i);
            getProjec.get(i).put("videoNum",StringUtils.isNotBlank(videoNum)?videoNum:"0");
            getProjec.get(i).put("monitoringCount",monitoringCount);
            getProjec.get(i).put("projectCount",Integer.valueOf(getProjec.get(i).get("projectCount").toString())+monitoringErrorCount);
            list.add(getProjec.get(i));
        }
        return list;
    }

    @Override
    public Object getDeptIdNext(Map<String, Object> map) {
        return ProjectInfoMapper.getDeptIdNext(map);
    }

    @Override
    public Object getCompanyJG(Map<String, Object> map) {
        Map<String,Object> twoMap =new HashMap<>();
//        if("2".equals(map.get("type"))){
//            twoMap.put("startTime", DateUtil.getStartTimes());
//            twoMap.put("endTime", DateUtil.getNowEndTime());
//        }
//        twoMap.put("deptId",map.get("deptId"));
//        twoMap.put("num",map.get("superiorCompanyId").toString().length()+4);
//        twoMap.put("num1",map.get("superiorCompanyId").toString().length());
//        twoMap.put("companyId",map.get("superiorCompanyId"));
        return ProjectInfoMapper.getCompanyQY(twoMap);
    }

    @Override
    public List<Map<String, Object>> getYCData(Map<String, Object> map) {
//        List<Map<String,Object>> list = new ArrayList<>();
//        JSONArray jsonArray = JSONArray.parseArray(map.get("projectData").toString());
//        for(int i = 0;i<jsonArray.size();i++){
//            if(jsonArray.getJSONObject(i).size()>3) {
//                Map<String, Object> ycMap = new HashMap<>();
//                ycMap.put("projectId", jsonArray.getJSONObject(i).getString("projectId"));
//                ycMap.put("startTime", DateUtil.getStartTimes());
//                ycMap.put("endTime", DateUtil.getNowEndTime());
//                //根据项目id查询扬尘数据
//                Integer YNnum = mapper.getYangchenCount(ycMap);
//                Map<String, Object> spMap = new HashMap<>();
//                spMap.put("projectName", jsonArray.getJSONObject(i).getString("projectName"));
//                spMap.put("startTime", DateUtil.getStartTimes());
//                spMap.put("endTime", DateUtil.getNowEndTime());
//                List<Map<String,Object>> shnum = projectVideoMapper.selectVideoOutline(spMap);
//                Integer dayCount = 0;
//                for(Map<String,Object> dayMap1:shnum){
//                    dayCount+= Integer.valueOf(dayMap1.get("value").toString());
//                }
//                //组装数据
//                Map<String, Object> zzMap = new HashMap<>();
//                zzMap.put("projectCount", YNnum);
//                zzMap.put("videoNum", dayCount);
//                zzMap.put("projectId", jsonArray.getJSONObject(i).getString("projectId"));
//                zzMap.put("projectName", jsonArray.getJSONObject(i).getString("projectName"));
//                zzMap.put("companyName", jsonArray.getJSONObject(i).getString("companyName"));
//                zzMap.put("projectAddress", jsonArray.getJSONObject(i).getString("projectAddress"));
//                list.add(zzMap);
//            }
//        }
        return null;//list;
    }


    @Override
    public Map<String, Object> getProjectPointCount(Map<String, Object> map) {
        //返回的Map
//        Map<String, Object> resultMap = new HashMap<>(16);
//        //根据选中的公司deptId查询所有的项目经纬度，和项目的总数
//        List<Map<String,Object>> list = new ArrayList<>();
//        List<Map<String, Object>> getProjectPoint = ProjectInfoMapper.selectProjectPoint(map.get("deptId").toString());
//        for(int i=0;i<getProjectPoint.size();i++){
//            getProjectPoint.get(i).put("id",i);
//            list.add(getProjectPoint.get(i));
//        }
//        //查询项目数量
//        int projectNum = ProjectInfoMapper.selectProjectSize(map.get("deptId").toString());
//        resultMap.put("projectPoint", list);
//        resultMap.put("projectNum", projectNum);
        return null;//resultMap;
    }

    @Override
    public List<Map<String, Object>> getProjectList(Map<String,Object> map) {
        List<Map<String,Object>> list = new ArrayList<>();
//        //根据参数查询所有的项目列表
//        List<Map<String, Object>> proList =  ProjectInfoMapper.selectProjectInfo(map);
//        proList.forEach(proMap->{
//            //查询出预警信息预警
//            Map<String,Object> PM25Map = new HashMap<>();
//            PM25Map.put("projectId",proMap.get("streamNumber"));
//            PM25Map.put("startTime", DateUtil.getStartTimes());
//            PM25Map.put("endTime", DateUtil.getNowEndTime());
//            int envirCount = mapper.getEarlyWarning(PM25Map);
//
//            //查询实时接入数据
//            String videoNum =  mapper.selectVideoByProjectName(proMap.get("name").toString());
//
//            //组装数据
//            Map<String,Object> dataMap = new HashMap<>();
//            dataMap.put("id",proMap.get("id"));
//            dataMap.put("engineeringName",proMap.get("engineeringName"));
//            dataMap.put("name",proMap.get("name"));
//            dataMap.put("projectAddress",proMap.get("projectAddress"));
//            dataMap.put("streamNumber",proMap.get("streamNumber"));
//            dataMap.put("envirCount",envirCount);
//            dataMap.put("videoNum",(videoNum == null)?'0':videoNum);
//            list.add(dataMap);
//        });
        return list;
    }

    @Override
    public Map<String, Object> getProjectBasicInfo(String id) {
        //根据项目的id查基本信息
        return ProjectInfoMapper.selectProjectOverview(id);
    }

    @Override
    public Map<String, Object> getProjectManageInfo(String id) {
        //根据项目的id查询管理信息
        return ProjectInfoMapper.selectProjectManage(id);
    }

    @Override
    public List<Map<String, Object>> getProjectInfoByName(Map<String, Object> map) {
        List<Map<String,Object>> list = new ArrayList<>();
        //1所有项目 2 预警项目
//        List<Map<String, Object>> getProjec  = ProjectInfoMapper.getProjectInfoByName(map);
//        for(int i=0;i<getProjec.size();i++){
//            //结构体监测预警个数
//            Integer monitoringErrorCount = appletsEnvironService.getMonitoringErrorCount(map);
//            if("1".equals(map.get("state").toString())){
//                //视频接入数
//                String videoNum = wxVideoMapper.getAccessVideoNum(getProjec.get(i).get("projectId").toString());
//                //结构体监测点位数
//                Integer monitoringCount = appletsEnvironService.getMonitoringList(getProjec.get(i));
//                getProjec.get(i).put("videoNum",StringUtils.isNotBlank(videoNum)?videoNum:"0");
//                getProjec.get(i).put("monitoringCount",monitoringCount);
//            }else {
//                getProjec.get(i).put("monitoringCount",monitoringErrorCount);
//            }
//            getProjec.get(i).put("id",i);
//            getProjec.get(i).put("projectCount",Integer.valueOf(getProjec.get(i).get("projectCount").toString())+monitoringErrorCount);
//        }
        return null;//getProjec;
    }

    @Override
    public void add() {
        List<Map<String,Object>> list = ProjectInfoMapper.getChinaProvince();
//        for(Map<String,Object> map:list){
//            try {
//                OkHttpClient client = new OkHttpClient().newBuilder()
//                        .build();
//                Request request = new Request.Builder()
//                        .url("http://datavmap-public.oss-cn-hangzhou.aliyuncs.com/areas/csv/"+map.get("adcode").toString()+"_district.json")
//                        .method("GET", null)
//                        .build();
//                Response response = client.newCall(request).execute();
//                String json = response.body().string();
//                System.out.println(json);
//                System.out.println("id=="+map.get("id"));
//                JSONArray object = JSON.parseObject(json).getJSONArray("rows");
//                List<Map<String,Object>> list1 = new ArrayList<>();
//                for(int i = 0;i<object.size();i++){
//                    Map<String,Object> data = new HashMap<>(16);
//                    data.put("areaName",object.getJSONObject(i).getString("name"));
//                    data.put("provinceId",map.get("provinceId"));
//                    data.put("provinceName",map.get("provinceName"));
//                    data.put("cityId",map.get("id"));
//                    data.put("cityName",object.getJSONObject(i).getString("parent"));
//                    data.put("adcode",object.getJSONObject(i).getString("adcode"));
//                    data.put("lat",object.getJSONObject(i).getString("lat"));
//                    data.put("lng",object.getJSONObject(i).getString("lng"));
//                    list1.add(data);
//                }
//                ProjectInfoMapper.addChinaCity(list1);
//            } catch (IOException e) {
//                e.printStackTrace();
//            }
//        }
    }

    @Override
    public List<Map<String, Object>> getProjectUnitList(String projectId) {
        return ProjectInfoMapper.getProjectUnitList(projectId);
    }

    /**
     * 查询子公司部门ID
     *
     * @param deptId 部门ID
     * @return 结果
     */
    private SysDept getZGSDept(Long deptId){
        SysDept sysDept = sysDeptMapper.selectDeptById(deptId);
        if("1".equals(sysDept.getTypeFlag())){
            //comFlag标识为1是子公司
            if("1".equals(sysDept.getComFlag())){
                return sysDept;
            }else{
                if("101".equals(Convert.toStr(sysDept.getDeptId()))){
                    return sysDept;
                }else{
                    return getZGSDept(sysDept.getParentId());
                }
            }
        }else{
            return sysDept;
        }
    }
}
