package com.yanzhu.jh.project.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.yanzhu.jh.project.mapper.SurProjectMapper;
import com.yanzhu.jh.project.domain.BaseBuildNode;
import com.yanzhu.jh.project.mapper.BaseBuildNodeMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yanzhu.jh.project.mapper.SurProjectBuildNodeDataMapper;
import com.yanzhu.jh.project.domain.SurProjectBuildNodeData;
import com.yanzhu.jh.project.service.ISurProjectBuildNodeDataService;
import com.ruoyi.common.utils.SecurityUtils;
/**
 * 项目建设节点数据Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-08-07
 */
@Service
public class SurProjectBuildNodeDataServiceImpl implements ISurProjectBuildNodeDataService 
{
    @Autowired
    private SurProjectBuildNodeDataMapper surProjectBuildNodeDataMapper;

    @Autowired
    private SurProjectMapper surProjectMapper;

    @Autowired
    private BaseBuildNodeMapper baseBuildNodeMapper;

    /**
     * 查询项目建设节点数据
     * 
     * @param id 项目建设节点数据主键
     * @return 项目建设节点数据
     */
    @Override
    public SurProjectBuildNodeData selectSurProjectBuildNodeDataById(Long id)
    {
        return surProjectBuildNodeDataMapper.selectSurProjectBuildNodeDataById(id);
    }

    /**
     * 查询项目建设节点数据列表
     * 
     * @param surProjectBuildNodeData 项目建设节点数据
     * @return 项目建设节点数据
     */
    @Override
    public List<SurProjectBuildNodeData> selectSurProjectBuildNodeDataList(SurProjectBuildNodeData surProjectBuildNodeData)
    {
        return surProjectBuildNodeDataMapper.selectSurProjectBuildNodeDataList(surProjectBuildNodeData);
    }

    /**
     * 新增项目建设节点数据
     * 
     * @param surProjectBuildNodeData 项目建设节点数据
     * @return 结果
     */
    @Override
    public int insertSurProjectBuildNodeData(SurProjectBuildNodeData surProjectBuildNodeData)
    {
        if(!SecurityUtils.getAuthentication().getPrincipal().equals("anonymousUser")) {
            surProjectBuildNodeData.setCreateBy(SecurityUtils.getUsername());
        }
        surProjectBuildNodeData.setCreateTime(DateUtils.getNowDate());
        return surProjectBuildNodeDataMapper.insertSurProjectBuildNodeData(surProjectBuildNodeData);
    }

    /**
     * 修改项目建设节点数据
     * 
     * @param surProjectBuildNodeData 项目建设节点数据
     * @return 结果
     */
    @Override
    public int updateSurProjectBuildNodeData(SurProjectBuildNodeData surProjectBuildNodeData)
    {
        surProjectBuildNodeData.setUpdateBy(SecurityUtils.getUsername());
        surProjectBuildNodeData.setUpdateTime(DateUtils.getNowDate());
        return surProjectBuildNodeDataMapper.updateSurProjectBuildNodeData(surProjectBuildNodeData);
    }

    /**
     * 批量删除项目建设节点数据
     * 
     * @param ids 需要删除的项目建设节点数据主键
     * @return 结果
     */
    @Override
    public int deleteSurProjectBuildNodeDataByIds(Long[] ids)
    {
        return surProjectBuildNodeDataMapper.deleteSurProjectBuildNodeDataByIds(ids);
    }

    /**
     * 删除项目建设节点数据信息
     * 
     * @param id 项目建设节点数据主键
     * @return 结果
     */
    @Override
    public int deleteSurProjectBuildNodeDataById(Long id)
    {
        return surProjectBuildNodeDataMapper.deleteSurProjectBuildNodeDataById(id);
    }

    @Override
    public int addProjectNodes(long projectId) {
        List<BaseBuildNode> list=baseBuildNodeMapper.selectByProject(projectId);
        int n=0;
        for(BaseBuildNode it :list){
            SurProjectBuildNodeData item=new SurProjectBuildNodeData();
            item.setProjectId(projectId);
            item.setNodeId(it.getId());
            n+=this.insertSurProjectBuildNodeData(item);
        }
        return n;
    }
}
